==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_texture.js <==
var class_ogre_1_1_texture =
[
    [ "Texture", "class_ogre_1_1_texture.html#a2624f89d5e9e5d645380fce79836b54f", null ],
    [ "~Texture", "class_ogre_1_1_texture.html#a0d93452e4b051453ec368bc275fe339f", null ],
    [ "setTextureType", "class_ogre_1_1_texture.html#a0ba4cefce02a7afa769a28c85c892082", null ],
    [ "getTextureType", "class_ogre_1_1_texture.html#a4d0ef43ff1e078b942e017f3dea6471d", null ],
    [ "getNumMipmaps", "class_ogre_1_1_texture.html#a2dca57a4b5847bc89f43819b779c8c6a", null ],
    [ "setNumMipmaps", "class_ogre_1_1_texture.html#a0ff2e6946c562128e059ebfcfc86d197", null ],
    [ "getMipmapsHardwareGenerated", "class_ogre_1_1_texture.html#a6f186da4d9557d958779eba68bb769a9", null ],
    [ "getGamma", "class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417", null ],
    [ "setGamma", "class_ogre_1_1_texture.html#ad8faaf7732b48e059f7d7dc15667f2af", null ],
    [ "setHardwareGammaEnabled", "class_ogre_1_1_texture.html#ae32d1cfbbb44d87d698aae547ecda35f", null ],
    [ "isHardwareGammaEnabled", "class_ogre_1_1_texture.html#a622c64d1862fb3accb017989cd1f1481", null ],
    [ "setFSAA", "class_ogre_1_1_texture.html#a4a4f09d971e96259593aac5ef0df873d", null ],
    [ "getFSAA", "class_ogre_1_1_texture.html#a2403b6aa5526f15570d26f8903e83da6", null ],
    [ "getFSAAHint", "class_ogre_1_1_texture.html#aef9b4ae468fdabbd98af5371f870437a", null ],
    [ "getHeight", "class_ogre_1_1_texture.html#a297b97d2c7253c1ca8c471b91edd4407", null ],
    [ "getWidth", "class_ogre_1_1_texture.html#ad1c33ba2014eeb134c8ce932f2a43418", null ],
    [ "getDepth", "class_ogre_1_1_texture.html#a743e5059501507cd858e90532e8263f9", null ],
    [ "getSrcHeight", "class_ogre_1_1_texture.html#aee3fd3170df592c3cc679cc38d3d9f60", null ],
    [ "getSrcWidth", "class_ogre_1_1_texture.html#aadcef30707e8e10fbac61d65e1e73e52", null ],
    [ "getSrcDepth", "class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99", null ],
    [ "setHeight", "class_ogre_1_1_texture.html#ae272c029efa4b04406a58e01cd8ea7e8", null ],
    [ "setWidth", "class_ogre_1_1_texture.html#a6f1a52798479255a174b3c0ecba6a10c", null ],
    [ "setDepth", "class_ogre_1_1_texture.html#aec390502f63927ed9470ba423ea66f64", null ],
    [ "getUsage", "class_ogre_1_1_texture.html#a4b9088dd0c1a9036e33dd64d56a3d902", null ],
    [ "setUsage", "class_ogre_1_1_texture.html#a7eded50cabb3e9dbeeee531c168016da", null ],
    [ "createInternalResources", "class_ogre_1_1_texture.html#ad3c315f415bb89c7646795bcee44acb7", null ],
    [ "freeInternalResources", "class_ogre_1_1_texture.html#adc238422174318f0d913baa6b6c7de45", null ],
    [ "copyToTexture", "class_ogre_1_1_texture.html#a017b0d0590ce4afc079f2f1f85a686b8", null ],
    [ "loadImage", "class_ogre_1_1_texture.html#a7bb75d68800a258c0ccaa34b3c23e2f2", null ],
    [ "loadRawData", "class_ogre_1_1_texture.html#a464f514c90dde429bcba7afb4b34768f", null ],
    [ "_loadImages", "class_ogre_1_1_texture.html#a353c91fed9eb4d4baada25f9519abc4a", null ],
    [ "getFormat", "class_ogre_1_1_texture.html#a8ed6a95810f21f53aa8cbc780b680164", null ],
    [ "getDesiredFormat", "class_ogre_1_1_texture.html#a5decc0244a000c5002935c32ac301f0c", null ],
    [ "getSrcFormat", "class_ogre_1_1_texture.html#a6ed49ed8701feb087b04b730ce1d682f", null ],
    [ "setFormat", "class_ogre_1_1_texture.html#a7c7b9de76ae4ffc29f4d75b6f9bf899a", null ],
    [ "hasAlpha", "class_ogre_1_1_texture.html#a7bd0ddb623f9d7b01fb272db8296cc72", null ],
    [ "setDesiredIntegerBitDepth", "class_ogre_1_1_texture.html#aba1e54055a50692510da87d5d3eb5de1", null ],
    [ "getDesiredIntegerBitDepth", "class_ogre_1_1_texture.html#aee662e54343ef66ec2835de723908735", null ],
    [ "setDesiredFloatBitDepth", "class_ogre_1_1_texture.html#a031474b97a9f2606cda91960b360aeb8", null ],
    [ "getDesiredFloatBitDepth", "class_ogre_1_1_texture.html#a90ce19013c81301e656ba110fcc01728", null ],
    [ "setDesiredBitDepths", "class_ogre_1_1_texture.html#a66da73db6e7117be285c62160da62d5c", null ],
    [ "setTreatLuminanceAsAlpha", "class_ogre_1_1_texture.html#a963616fe631db2b5bef45234a15bff7f", null ],
    [ "getNumFaces", "class_ogre_1_1_texture.html#ab81b8c120556a1edf4c42d92abc9baf4", null ],
    [ "getBuffer", "class_ogre_1_1_texture.html#a38381942fa75cba53a03813047d5a2ee", null ],
    [ "convertToImage", "class_ogre_1_1_texture.html#a6c5c6be0ec434481a055ab6b03b644fd", null ],
    [ "getCustomAttribute", "class_ogre_1_1_texture.html#accfa5467ab8ccfc5920ec64101f8f532", null ],
    [ "getCustomAttribute", "class_ogre_1_1_texture.html#a4b257658297582848fe47a027f75bb3a", null ],
    [ "createShaderAccessPoint", "class_ogre_1_1_texture.html#ad233adde489a5b2129eb20fc93952839", null ],
    [ "setLayerNames", "class_ogre_1_1_texture.html#aa539a94d1bd9ea8f4e804093be538c3e", null ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_texture.js <==
var class_ogre_1_1_texture =
[
    [ "Texture", "class_ogre_1_1_texture.html#a2624f89d5e9e5d645380fce79836b54f", null ],
    [ "~Texture", "class_ogre_1_1_texture.html#a0d93452e4b051453ec368bc275fe339f", null ],
    [ "setTextureType", "class_ogre_1_1_texture.html#a0ba4cefce02a7afa769a28c85c892082", null ],
    [ "getTextureType", "class_ogre_1_1_texture.html#a4d0ef43ff1e078b942e017f3dea6471d", null ],
    [ "_setD3D11Surface", "class_ogre_1_1_texture.html#aed5a7915c939adae12ed3313d4d1f9c0", null ],
    [ "getNumMipmaps", "class_ogre_1_1_texture.html#a2dca57a4b5847bc89f43819b779c8c6a", null ],
    [ "setNumMipmaps", "class_ogre_1_1_texture.html#a0ff2e6946c562128e059ebfcfc86d197", null ],
    [ "getMipmapsHardwareGenerated", "class_ogre_1_1_texture.html#a6f186da4d9557d958779eba68bb769a9", null ],
    [ "getGamma", "class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417", null ],
    [ "setGamma", "class_ogre_1_1_texture.html#ad8faaf7732b48e059f7d7dc15667f2af", null ],
    [ "setHardwareGammaEnabled", "class_ogre_1_1_texture.html#ae32d1cfbbb44d87d698aae547ecda35f", null ],
    [ "isHardwareGammaEnabled", "class_ogre_1_1_texture.html#a622c64d1862fb3accb017989cd1f1481", null ],
    [ "setFSAA", "class_ogre_1_1_texture.html#a4a4f09d971e96259593aac5ef0df873d", null ],
    [ "getFSAA", "class_ogre_1_1_texture.html#a2403b6aa5526f15570d26f8903e83da6", null ],
    [ "getFSAAHint", "class_ogre_1_1_texture.html#aef9b4ae468fdabbd98af5371f870437a", null ],
    [ "getHeight", "class_ogre_1_1_texture.html#a297b97d2c7253c1ca8c471b91edd4407", null ],
    [ "getWidth", "class_ogre_1_1_texture.html#ad1c33ba2014eeb134c8ce932f2a43418", null ],
    [ "getDepth", "class_ogre_1_1_texture.html#a743e5059501507cd858e90532e8263f9", null ],
    [ "getSrcHeight", "class_ogre_1_1_texture.html#aee3fd3170df592c3cc679cc38d3d9f60", null ],
    [ "getSrcWidth", "class_ogre_1_1_texture.html#aadcef30707e8e10fbac61d65e1e73e52", null ],
    [ "getSrcDepth", "class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99", null ],
    [ "setHeight", "class_ogre_1_1_texture.html#ae272c029efa4b04406a58e01cd8ea7e8", null ],
    [ "setWidth", "class_ogre_1_1_texture.html#a6f1a52798479255a174b3c0ecba6a10c", null ],
    [ "setDepth", "class_ogre_1_1_texture.html#aec390502f63927ed9470ba423ea66f64", null ],
    [ "getUsage", "class_ogre_1_1_texture.html#a4b9088dd0c1a9036e33dd64d56a3d902", null ],
    [ "setUsage", "class_ogre_1_1_texture.html#a7eded50cabb3e9dbeeee531c168016da", null ],
    [ "createInternalResources", "class_ogre_1_1_texture.html#ad3c315f415bb89c7646795bcee44acb7", null ],
    [ "copyToTexture", "class_ogre_1_1_texture.html#a017b0d0590ce4afc079f2f1f85a686b8", null ],
    [ "loadImage", "class_ogre_1_1_texture.html#a7bb75d68800a258c0ccaa34b3c23e2f2", null ],
    [ "loadRawData", "class_ogre_1_1_texture.html#a464f514c90dde429bcba7afb4b34768f", null ],
    [ "_loadImages", "class_ogre_1_1_texture.html#a353c91fed9eb4d4baada25f9519abc4a", null ],
    [ "getFormat", "class_ogre_1_1_texture.html#a8ed6a95810f21f53aa8cbc780b680164", null ],
    [ "getDesiredFormat", "class_ogre_1_1_texture.html#a5decc0244a000c5002935c32ac301f0c", null ],
    [ "getSrcFormat", "class_ogre_1_1_texture.html#a6ed49ed8701feb087b04b730ce1d682f", null ],
    [ "setFormat", "class_ogre_1_1_texture.html#a7c7b9de76ae4ffc29f4d75b6f9bf899a", null ],
    [ "hasAlpha", "class_ogre_1_1_texture.html#a7bd0ddb623f9d7b01fb272db8296cc72", null ],
    [ "setDesiredIntegerBitDepth", "class_ogre_1_1_texture.html#aba1e54055a50692510da87d5d3eb5de1", null ],
    [ "getDesiredIntegerBitDepth", "class_ogre_1_1_texture.html#aee662e54343ef66ec2835de723908735", null ],
    [ "setDesiredFloatBitDepth", "class_ogre_1_1_texture.html#a031474b97a9f2606cda91960b360aeb8", null ],
    [ "getDesiredFloatBitDepth", "class_ogre_1_1_texture.html#a90ce19013c81301e656ba110fcc01728", null ],
    [ "setDesiredBitDepths", "class_ogre_1_1_texture.html#a66da73db6e7117be285c62160da62d5c", null ],
    [ "setTreatLuminanceAsAlpha", "class_ogre_1_1_texture.html#a963616fe631db2b5bef45234a15bff7f", null ],
    [ "getNumFaces", "class_ogre_1_1_texture.html#ab81b8c120556a1edf4c42d92abc9baf4", null ],
    [ "getNumLayers", "class_ogre_1_1_texture.html#a6bb2b36161be51be48cea882f6d4cfee", null ],
    [ "getRenderTarget", "class_ogre_1_1_texture.html#ad512f6f88086986f58b36bf526ce4631", null ],
    [ "getBuffer", "class_ogre_1_1_texture.html#a0e27aa7d2f734ff39d706e7ff6577cf9", null ],
    [ "convertToImage", "class_ogre_1_1_texture.html#a6c5c6be0ec434481a055ab6b03b644fd", null ],
    [ "getCustomAttribute", "class_ogre_1_1_texture.html#accfa5467ab8ccfc5920ec64101f8f532", null ],
    [ "getCustomAttribute", "class_ogre_1_1_texture.html#a4b257658297582848fe47a027f75bb3a", null ],
    [ "createShaderAccessPoint", "class_ogre_1_1_texture.html#ad233adde489a5b2129eb20fc93952839", null ],
    [ "setLayerNames", "class_ogre_1_1_texture.html#aa539a94d1bd9ea8f4e804093be538c3e", null ]
];
